@@ -5,7 +5,7 @@ import requests
 import math
 
 from typing import List, Dict, Optional
-
+from loguru import logger
 
 class Connection:
     def __init__(self, org_id: int):
@@ -117,15 +117,18 @@ class Connection:
             params["flow_uuid"] = flow_uuid
 
         # Call Report API is Paginated so data is saved in pages, each page will be a get request
+        logger.info(params)
 
         first_page = self._get_request("call", params)
         current_page = first_page.get("page", 1)
         total_pages = first_page.get("total_pages", 2)
         call_summary = first_page.get("items", [])
         pages_to_read = random.sample(range(current_page, total_pages), PAGE_SCAN_LIMIT)
+        logger.info(f"Reading random {pages_to_read} pages.")
 
         for page in pages_to_read:
             params["page"] = page
+            logger.info(params)
             items = self._get_request("call", params).get("items", [])
             call_summary.extend(items)
 
